==> rendition-11.13.0.tgz: package/dist_esm5/components/Tag/index.js <==
import { __makeTemplateObject } from "tslib";
import * as React from 'react';
import FaClose from 'react-icons/lib/fa/close';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import Button from '../Button';
import { Flex } from '../Grid';
import Txt from '../Txt';
var Container = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tbackground-color: ", ";\n\tborder: 1px solid ", ";\n\tborder-radius: 2px;\n\tline-height: 1.5;\n"], ["\n\tbackground-color: ", ";\n\tborder: 1px solid ", ";\n\tborder-radius: 2px;\n\tline-height: 1.5;\n"])), function (props) { return props.theme.colors.info.light; }, function (props) { return props.theme.colors.info.main; });
var TagText = styled(Txt)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tfont-family: ", ";\n"], ["\n\tfont-family: ", ";\n"])), function (props) { return props.theme.titleFont; });
var DeleteButton = styled(Button)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tcolor: ", ";\n"], ["\n\tcolor: ", ";\n"])), function (props) { return props.theme.colors.tertiary.semilight; });
var TagBase = function (_a) {
    var name = _a.name, operator = _a.operator, value = _a.value, multiple = _a.multiple, onClose = _a.onClose, onClick = _a.onClick, className = _a.className;
    var tagArray = multiple || [{ name: name, operator: operator, value: value }];
    var tagContent = (React.createElement(Container, { py: 1, px: 2 }, tagArray.map(function (tagEntry, index) {
        var nameValueSeparator = tagEntry.operator
            ? " " + tagEntry.operator + " "
            : ': ';
        return (React.createElement(React.Fragment, { key: index },
            index > 0 && (React.createElement(Txt, { whitespace: "pre", color: "info.main", fontSize: 0, italic: true }, "  " + (tagEntry.prefix || ',') + "  ")),
            !tagEntry.value && !tagEntry.name && (React.createElement(TagText, { italic: true, color: "info.main", fontSize: 0 }, "no value")),
            tagEntry.name && (React.createElement(TagText, { whitespace: "pre", color: "info.main", fontSize: 0 }, "" + tagEntry.name + (tagEntry.value ? nameValueSeparator : ''))),
            tagEntry.value && (React.createElement(TagText, { bold: true, color: "info.main", fontSize: 0 }, tagEntry.value))));
    })));
    return (React.createElement(Flex, { className: className },
        onClick ? (React.createElement(Button, { plain: true, onClick: onClick }, tagContent)) : (tagContent),
        onClose && (React.createElement(DeleteButton, { plain: true, p: 1, pl: 2, pr: 3, fontSize: 0, onClick: onClose },
            React.createElement(FaClose, null)))));
};
export var Tag = asRendition(TagBase);
var templateObject_1, templateObject_2, templateObject_3;

==> rendition-11.16.1.tgz: package/dist_esm5/components/Tag/index.js <==
import { __makeTemplateObject } from "tslib";
import * as React from 'react';
import FaClose from 'react-icons/lib/fa/close';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import Button from '../Button';
import { Flex } from '../Flex';
import Txt from '../Txt';
var Container = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tbackground-color: ", ";\n\tborder: 1px solid ", ";\n\tborder-radius: 2px;\n\tline-height: 1.5;\n"], ["\n\tbackground-color: ", ";\n\tborder: 1px solid ", ";\n\tborder-radius: 2px;\n\tline-height: 1.5;\n"])), function (props) { return props.theme.colors.info.light; }, function (props) { return props.theme.colors.info.main; });
var TagText = styled(Txt)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tfont-family: ", ";\n"], ["\n\tfont-family: ", ";\n"])), function (props) { return props.theme.titleFont; });
var DeleteButton = styled(Button)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tcolor: ", ";\n"], ["\n\tcolor: ", ";\n"])), function (props) { return props.theme.colors.tertiary.semilight; });
var TagBase = function (_a) {
    var name = _a.name, operator = _a.operator, value = _a.value, multiple = _a.multiple, onClose = _a.onClose, onClick = _a.onClick, className = _a.className;
    var tagArray = multiple || [{ name: name, operator: operator, value: value }];
    var tagContent = (React.createElement(Container, { py: 1, px: 2 }, tagArray.map(function (tagEntry, index) {
        var nameValueSeparator = tagEntry.operator
            ? " " + tagEntry.operator + " "
            : ': ';
        return (React.createElement(React.Fragment, { key: index },
            index > 0 && (React.createElement(Txt, { whitespace: "pre", color: "info.main", fontSize: 0, italic: true }, "  " + (tagEntry.prefix || ',') + "  ")),
            !tagEntry.value && !tagEntry.name && (React.createElement(TagText, { italic: true, color: "info.main", fontSize: 0 }, "no value")),
            tagEntry.name && (React.createElement(TagText, { whitespace: "pre", color: "info.main", fontSize: 0 }, "" + tagEntry.name + (tagEntry.value ? nameValueSeparator : ''))),
            tagEntry.value && (React.createElement(TagText, { bold: true, color: "info.main", fontSize: 0 }, tagEntry.value))));
    })));
    return (React.createElement(Flex, { className: className },
        onClick ? (React.createElement(Button, { plain: true, onClick: onClick }, tagContent)) : (tagContent),
        onClose && (React.createElement(DeleteButton, { plain: true, p: 1, pl: 2, pr: 3, fontSize: 0, onClick: onClose },
            React.createElement(FaClose, null)))));
};
export var Tag = asRendition(TagBase);
var templateObject_1, templateObject_2, templateObject_3;
